use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/Webservice/Judobase.pm',
    'lib/Webservice/Judobase.pod',
    'lib/Webservice/Judobase/Competitor.pm',
    'lib/Webservice/Judobase/Contests.pm',
    'lib/Webservice/Judobase/General.pm',
    't/00-Basic.t',
    't/00-compile.t',
    't/competitor/best_results.t',
    't/competitor/birthdays_competitors.t',
    't/competitor/contests.t',
    't/competitor/contests_statistics.t',
    't/competitor/fights_statistics.t',
    't/competitor/info.t',
    't/competitor/wrl.t',
    't/contests/competition.t',
    't/general/competition.t'
);

notabs_ok($_) foreach @files;
done_testing;
